import React from 'react';
import Link from "@docusaurus/Link";
import Slider from "react-slick";
import "slick-carousel/slick/slick.css";
import "slick-carousel/slick/slick-theme.css";
import clsx from 'clsx';
import styles from './styles.module.css';
import useBaseUrl from "@docusaurus/useBaseUrl";

const FeatureList = [
  {
    title: 'Christophe Chaudier',
    subtitle: 'Formateur et Consultant en méthodologies DevOps',
    img: 'img/team/cchaudier_bkg.png',
    description: (
      <>
        Formateur et Consultant en méthodologies DevOps et expert en déploiement logiciel. Actif sur les réseaux sociaux @c_chaudier. Saint-Étienne, 40 ans, 20 ans d’expérience. Étant expert en déploiements automatisés, Christophe a en charge la partie « R&D opérationnelle » dans le but d’automatiser la plateforme de service et le déploiement des logiciels. Christophe est également en charge de la coordination et de la formation des consultants Lydra. Ayant le plus d’expérience avec les hébergeurs de plateforme en ligne, Christophe est responsable de la relation commerciale et technique avec ces fournisseurs de solutions d’hébergement de serveurs.
      </>
    ),
  },
  {
    title: 'Thomas Michel',
    subtitle: 'Administrateur système et conseil en logiciels libres',
    img: 'img/team/tmichel_bkg.png',
    description: (
      <>
        Administrateur système et conseil en logiciels libres. Rennes, 35 ans, 13 ans d’expérience. Déjà opérationnel dans la recherche d’outils numériques libres pour les offres « clé en main », Thomas a en charge la partie « R&D fonctionnelle » consistant à identifier les logiciels les plus adaptés pour répondre à un besoin, et documenter leur processus de déploiement et de paramétrage. De part son expérience dans la mise à disposition de services en ligne « clé en main », Thomas est également au pilotage des travaux légaux et institutionnels. Thomas a aussi la responsabilité de coordonner les travaux de documentation utilisateur et de support à la clientèle.
      </>
    ),
  },

];

const Nouveau =   {
  title: 'Pourquoi pas toi ?',
  subtitle: "Rejoins Lydra ",
  img: 'img/team/hacker.png',
  link: "/contacts"
}

function Feature({img, title, subtitle, description, link}) {
  if (link) {
    return (
      <Link className={styles.featureElement} to={link}>
        <img src={useBaseUrl(img)} className={styles.featureSvg} role="img" />
        <div className="text--center padding-horiz--md">
          <h3>{title}</h3>
          <p> <b>{subtitle}</b></p>
          {description && (
            <p>{description}</p>
          )
          }
          
        </div>
      </Link>
    );
  } else {
    return (
      <div className={styles.featureElement}>
        <img src={useBaseUrl(img)} className={styles.featureSvg} role="img" />
        <div className="text--center padding-horiz--md">
          <h3>{title}</h3>
          <p> <b>{subtitle}</b></p>
          {description && (
            <p>{description}</p>
          )
          }
        </div>
      </div>
    );
  }

}

export default function HomepageTeam() {
  const settings = {
    accessibility: true,
    infinite: false,
    speed: 500,
    slidesToShow: 2,
    slidesToScroll: 1,
    responsive: [
      {
        breakpoint: 720,
        settings: {
          slidesToShow: 1,
          slidesToScroll: 1,
          initialSlide: 0
        }
      },
    ]
  };
  return (
    <section id="team">
      <h2 className='text--center margin-top--lg'> Notre Équipe </h2>
      <div className={styles.features + ' team'}>
        <div className="container">
          <div className="row">
            <div className={clsx('col col--8')}>
            <Slider {...settings}>
            {FeatureList.map((props, idx) => (
                <Feature key={idx} {...props} />
              ))}
            </Slider>
            </div>
            <Feature {...Nouveau}/>
          </div>
        </div>
      </div>
    </section>
  );
}
